# DICOM Modality-Specific Metadata Extraction

::: imgtools.dicom.dicom_metadata.extract_metadata

::: imgtools.dicom.dicom_metadata.extractor_base.ModalityMetadataExtractor

::: imgtools.dicom.dicom_metadata.extractors.FallbackMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']

::: imgtools.dicom.dicom_metadata.extractors.CTMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']

::: imgtools.dicom.dicom_metadata.extractors.MRMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']
    
::: imgtools.dicom.dicom_metadata.extractors.PTMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']
    
::: imgtools.dicom.dicom_metadata.extractors.SEGMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']
    
::: imgtools.dicom.dicom_metadata.extractors.RTSTRUCTMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']

::: imgtools.dicom.dicom_metadata.extractors.RTDOSEMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']

::: imgtools.dicom.dicom_metadata.extractors.RTPLANMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']

::: imgtools.dicom.dicom_metadata.extractors.SRMetadataExtractor
    options:
        members: ['modality_tags', 'computed_fields']